**Required:** write a single sentence that describes the changes made by this pull request.

### PR checklist
<!--
Do not delete any of the following items. If one is not required,
strike it out and leave a note explaining why. For example:

- ~Update documentation~ N/A; bug fix
-->
- [ ] Checks all ✅
- [ ] Update documentation
- [ ] Update doc/whatsnew.rst
